@@ -6,7 +6,7 @@ package Dist::Zilla::PluginBundle::ZURBORG;
 
 use Moose;
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -67,6 +67,8 @@ sub configure {
         'TestRelease' => {},
         'ConfirmRelease' => {},
         'UploadToCPAN' => {},
+        'Git::Push' => {},
+        'GitHub::UploadRelease' => {},
     );
 
     for (0 .. $#plugins/2) {
@@ -88,7 +90,7 @@ Dist::Zilla::PluginBundle::ZURBORG - dzil plugin bundle of ZURBORG
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 METHODS
 
